"use client"

import { useState } from "react"
import { useRouter } from "next/navigation"
import { Button } from "@/components/ui/button"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card"
import { Textarea } from "@/components/ui/textarea"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { PlusCircle, Trash2, Save, LogOut } from "lucide-react"
import { useContent } from "../../components/content-provider"
import { TokenLogo } from "../../components/token-logo"

export default function AdminDashboard() {
  const { content, isLoading, updateContent, saveContent } = useContent()
  const [isSaving, setIsSaving] = useState(false)
  const [activeTab, setActiveTab] = useState("hero")
  const router = useRouter()

  const handleLogout = async () => {
    try {
      await fetch("/api/auth/logout", { method: "POST" })
      router.push("/login")
    } catch (error) {
      console.error("Error logging out:", error)
    }
  }

  const handleSaveSection = async (section: string) => {
    setIsSaving(true)
    try {
      const success = await saveContent()
      if (success) {
        alert("Content saved successfully!")
      } else {
        alert("Content saved to local storage only. Changes will be visible but not persisted to the server.")
      }
    } catch (error) {
      console.error("Error saving content:", error)
      alert("An error occurred while saving content")
    } finally {
      setIsSaving(false)
    }
  }

  const handleAddItem = (section: string) => {
    if (section === "features" || section === "roadmap" || section === "tokenomics" || section === "advantages") {
      const newItem =
        section === "features"
          ? { title: "New Feature", items: ["New item"] }
          : { title: "New Item", description: "Description here" }

      updateContent(section, [...content[section], newItem])
    } else if (section === "communities") {
      updateContent("communities", [
        ...content.communities,
        { name: "New Platform", icon: "MessageCircle", description: "Description here", url: "https://example.com" },
      ])
    }
  }

  const handleRemoveItem = (section: string, index: number) => {
    updateContent(
      section,
      content[section].filter((_: any, i: number) => i !== index),
    )
  }

  const handleFeatureItemChange = (featureIndex: number, itemIndex: number, value: string) => {
    const updatedFeatures = [...content.features]
    updatedFeatures[featureIndex].items[itemIndex] = value
    updateContent("features", updatedFeatures)
  }

  const handleAddFeatureItem = (featureIndex: number) => {
    const updatedFeatures = [...content.features]
    updatedFeatures[featureIndex].items.push("New item")
    updateContent("features", updatedFeatures)
  }

  const handleRemoveFeatureItem = (featureIndex: number, itemIndex: number) => {
    const updatedFeatures = [...content.features]
    updatedFeatures[featureIndex].items = updatedFeatures[featureIndex].items.filter(
      (_: any, i: number) => i !== itemIndex,
    )
    updateContent("features", updatedFeatures)
  }

  if (isLoading) {
    return (
      <div className="min-h-screen flex items-center justify-center bg-gradient-to-b from-blue-900 via-indigo-900 to-purple-900">
        <p className="text-white">Loading...</p>
      </div>
    )
  }

  return (
    <div className="min-h-screen bg-gradient-to-b from-blue-900 via-indigo-900 to-purple-900 p-4">
      <div className="max-w-6xl mx-auto">
        <div className="flex flex-col md:flex-row justify-between items-center mb-6 gap-4">
          <div className="w-full md:w-auto">
            <TokenLogo size="small" />
          </div>
          <div className="flex items-center">
            <h2 className="text-xl font-playfair text-white mr-4">Admin Dashboard</h2>
            <Button variant="outline" onClick={handleLogout} className="text-white">
              <LogOut className="mr-2 h-4 w-4" /> Logout
            </Button>
          </div>
        </div>

        <Tabs value={activeTab} onValueChange={setActiveTab} className="space-y-4">
          <TabsList className="grid grid-cols-3 md:grid-cols-7 bg-white/10">
            <TabsTrigger value="hero" className="text-white">
              Hero
            </TabsTrigger>
            <TabsTrigger value="features" className="text-white">
              Features
            </TabsTrigger>
            <TabsTrigger value="roadmap" className="text-white">
              Roadmap
            </TabsTrigger>
            <TabsTrigger value="tokenomics" className="text-white">
              Tokenomics
            </TabsTrigger>
            <TabsTrigger value="advantages" className="text-white">
              Advantages
            </TabsTrigger>
            <TabsTrigger value="communities" className="text-white">
              Communities
            </TabsTrigger>
            <TabsTrigger value="settings" className="text-white">
              Settings
            </TabsTrigger>
          </TabsList>

          <TabsContent value="hero" className="space-y-4">
            <Card className="bg-white/10 backdrop-blur-lg border-gray-200">
              <CardHeader>
                <CardTitle className="text-xl font-playfair text-white">Hero Section</CardTitle>
              </CardHeader>
              <CardContent className="space-y-4">
                <div className="space-y-2">
                  <Label htmlFor="hero-title" className="text-white">
                    Title
                  </Label>
                  <Input
                    id="hero-title"
                    value={content.hero.title}
                    onChange={(e) => updateContent("hero", { ...content.hero, title: e.target.value })}
                    className="bg-white/20 border-white/30 text-white"
                  />
                </div>
                <div className="space-y-2">
                  <Label htmlFor="hero-description" className="text-white">
                    Description
                  </Label>
                  <Textarea
                    id="hero-description"
                    value={content.hero.description}
                    onChange={(e) => updateContent("hero", { ...content.hero, description: e.target.value })}
                    className="bg-white/20 border-white/30 text-white min-h-[100px]"
                  />
                </div>
                <Button
                  onClick={() => handleSaveSection("hero")}
                  disabled={isSaving}
                  className="bg-green-500 hover:bg-green-600"
                >
                  <Save className="mr-2 h-4 w-4" />
                  {isSaving ? "Saving..." : "Save Changes"}
                </Button>
              </CardContent>
            </Card>
          </TabsContent>

          <TabsContent value="features" className="space-y-4">
            <div className="flex justify-between items-center">
              <h2 className="text-xl font-playfair text-white">Features</h2>
              <Button onClick={() => handleAddItem("features")} variant="outline" className="text-white">
                <PlusCircle className="mr-2 h-4 w-4" /> Add Feature
              </Button>
            </div>

            {content.features.map((feature: any, index: number) => (
              <Card key={index} className="bg-white/10 backdrop-blur-lg border-gray-200">
                <CardHeader className="flex flex-row items-center justify-between">
                  <CardTitle className="text-lg font-playfair text-white">Feature {index + 1}</CardTitle>
                  <Button
                    variant="ghost"
                    onClick={() => handleRemoveItem("features", index)}
                    className="text-red-400 hover:text-red-300 hover:bg-red-900/20"
                  >
                    <Trash2 className="h-4 w-4" />
                  </Button>
                </CardHeader>
                <CardContent className="space-y-4">
                  <div className="space-y-2">
                    <Label htmlFor={`feature-${index}-title`} className="text-white">
                      Title
                    </Label>
                    <Input
                      id={`feature-${index}-title`}
                      value={feature.title}
                      onChange={(e) => {
                        const updatedFeatures = [...content.features]
                        updatedFeatures[index].title = e.target.value
                        updateContent("features", updatedFeatures)
                      }}
                      className="bg-white/20 border-white/30 text-white"
                    />
                  </div>

                  <div className="space-y-2">
                    <div className="flex justify-between items-center">
                      <Label className="text-white">Items</Label>
                      <Button
                        variant="outline"
                        size="sm"
                        onClick={() => handleAddFeatureItem(index)}
                        className="text-white text-xs"
                      >
                        <PlusCircle className="mr-1 h-3 w-3" /> Add Item
                      </Button>
                    </div>

                    {feature.items.map((item: string, itemIndex: number) => (
                      <div key={itemIndex} className="flex gap-2">
                        <Input
                          value={item}
                          onChange={(e) => handleFeatureItemChange(index, itemIndex, e.target.value)}
                          className="bg-white/20 border-white/30 text-white flex-1"
                        />
                        <Button
                          variant="ghost"
                          size="icon"
                          onClick={() => handleRemoveFeatureItem(index, itemIndex)}
                          className="text-red-400 hover:text-red-300 hover:bg-red-900/20"
                        >
                          <Trash2 className="h-4 w-4" />
                        </Button>
                      </div>
                    ))}
                  </div>
                </CardContent>
              </Card>
            ))}

            <Button
              onClick={() => handleSaveSection("features")}
              disabled={isSaving}
              className="bg-green-500 hover:bg-green-600"
            >
              <Save className="mr-2 h-4 w-4" />
              {isSaving ? "Saving..." : "Save Changes"}
            </Button>
          </TabsContent>

          <TabsContent value="roadmap" className="space-y-4">
            <div className="flex justify-between items-center">
              <h2 className="text-xl font-playfair text-white">Roadmap</h2>
              <Button onClick={() => handleAddItem("roadmap")} variant="outline" className="text-white">
                <PlusCircle className="mr-2 h-4 w-4" /> Add Roadmap Item
              </Button>
            </div>

            {content.roadmap.map((roadmapItem: any, index: number) => (
              <Card key={index} className="bg-white/10 backdrop-blur-lg border-gray-200">
                <CardHeader className="flex flex-row items-center justify-between">
                  <CardTitle className="text-lg font-playfair text-white">Roadmap Item {index + 1}</CardTitle>
                  <Button
                    variant="ghost"
                    onClick={() => handleRemoveItem("roadmap", index)}
                    className="text-red-400 hover:text-red-300 hover:bg-red-900/20"
                  >
                    <Trash2 className="h-4 w-4" />
                  </Button>
                </CardHeader>
                <CardContent className="space-y-4">
                  <div className="space-y-2">
                    <Label htmlFor={`roadmap-${index}-title`} className="text-white">
                      Title
                    </Label>
                    <Input
                      id={`roadmap-${index}-title`}
                      value={roadmapItem.title}
                      onChange={(e) => {
                        const updatedRoadmap = [...content.roadmap]
                        updatedRoadmap[index].title = e.target.value
                        updateContent("roadmap", updatedRoadmap)
                      }}
                      className="bg-white/20 border-white/30 text-white"
                    />
                  </div>

                  <div className="space-y-2">
                    <Label htmlFor={`roadmap-${index}-description`} className="text-white">
                      Description
                    </Label>
                    <Textarea
                      id={`roadmap-${index}-description`}
                      value={roadmapItem.description}
                      onChange={(e) => {
                        const updatedRoadmap = [...content.roadmap]
                        updatedRoadmap[index].description = e.target.value
                        updateContent("roadmap", updatedRoadmap)
                      }}
                      className="bg-white/20 border-white/30 text-white min-h-[100px]"
                    />
                  </div>
                </CardContent>
              </Card>
            ))}

            <Button
              onClick={() => handleSaveSection("roadmap")}
              disabled={isSaving}
              className="bg-green-500 hover:bg-green-600"
            >
              <Save className="mr-2 h-4 w-4" />
              {isSaving ? "Saving..." : "Save Changes"}
            </Button>
          </TabsContent>

          <TabsContent value="tokenomics" className="space-y-4">
            <div className="flex justify-between items-center">
              <h2 className="text-xl font-playfair text-white">Tokenomics</h2>
              <Button onClick={() => handleAddItem("tokenomics")} variant="outline" className="text-white">
                <PlusCircle className="mr-2 h-4 w-4" /> Add Tokenomics Item
              </Button>
            </div>

            {content.tokenomics.map((tokenomicsItem: any, index: number) => (
              <Card key={index} className="bg-white/10 backdrop-blur-lg border-gray-200">
                <CardHeader className="flex flex-row items-center justify-between">
                  <CardTitle className="text-lg font-playfair text-white">Tokenomics Item {index + 1}</CardTitle>
                  <Button
                    variant="ghost"
                    onClick={() => handleRemoveItem("tokenomics", index)}
                    className="text-red-400 hover:text-red-300 hover:bg-red-900/20"
                  >
                    <Trash2 className="h-4 w-4" />
                  </Button>
                </CardHeader>
                <CardContent className="space-y-4">
                  <div className="space-y-2">
                    <Label htmlFor={`tokenomics-${index}-title`} className="text-white">
                      Title
                    </Label>
                    <Input
                      id={`tokenomics-${index}-title`}
                      value={tokenomicsItem.title}
                      onChange={(e) => {
                        const updatedTokenomics = [...content.tokenomics]
                        updatedTokenomics[index].title = e.target.value
                        updateContent("tokenomics", updatedTokenomics)
                      }}
                      className="bg-white/20 border-white/30 text-white"
                    />
                  </div>

                  <div className="space-y-2">
                    <Label htmlFor={`tokenomics-${index}-description`} className="text-white">
                      Description
                    </Label>
                    <Textarea
                      id={`tokenomics-${index}-description`}
                      value={tokenomicsItem.description}
                      onChange={(e) => {
                        const updatedTokenomics = [...content.tokenomics]
                        updatedTokenomics[index].description = e.target.value
                        updateContent("tokenomics", updatedTokenomics)
                      }}
                      className="bg-white/20 border-white/30 text-white min-h-[100px]"
                    />
                  </div>
                </CardContent>
              </Card>
            ))}

            <Button
              onClick={() => handleSaveSection("tokenomics")}
              disabled={isSaving}
              className="bg-green-500 hover:bg-green-600"
            >
              <Save className="mr-2 h-4 w-4" />
              {isSaving ? "Saving..." : "Save Changes"}
            </Button>
          </TabsContent>

          <TabsContent value="advantages" className="space-y-4">
            <div className="flex justify-between items-center">
              <h2 className="text-xl font-playfair text-white">Advantages</h2>
              <Button onClick={() => handleAddItem("advantages")} variant="outline" className="text-white">
                <PlusCircle className="mr-2 h-4 w-4" /> Add Advantage Item
              </Button>
            </div>

            {content.advantages.map((advantageItem: any, index: number) => (
              <Card key={index} className="bg-white/10 backdrop-blur-lg border-gray-200">
                <CardHeader className="flex flex-row items-center justify-between">
                  <CardTitle className="text-lg font-playfair text-white">Advantage Item {index + 1}</CardTitle>
                  <Button
                    variant="ghost"
                    onClick={() => handleRemoveItem("advantages", index)}
                    className="text-red-400 hover:text-red-300 hover:bg-red-900/20"
                  >
                    <Trash2 className="h-4 w-4" />
                  </Button>
                </CardHeader>
                <CardContent className="space-y-4">
                  <div className="space-y-2">
                    <Label htmlFor={`advantages-${index}-title`} className="text-white">
                      Title
                    </Label>
                    <Input
                      id={`advantages-${index}-title`}
                      value={advantageItem.title}
                      onChange={(e) => {
                        const updatedAdvantages = [...content.advantages]
                        updatedAdvantages[index].title = e.target.value
                        updateContent("advantages", updatedAdvantages)
                      }}
                      className="bg-white/20 border-white/30 text-white"
                    />
                  </div>

                  <div className="space-y-2">
                    <Label htmlFor={`advantages-${index}-description`} className="text-white">
                      Description
                    </Label>
                    <Textarea
                      id={`advantages-${index}-description`}
                      value={advantageItem.description}
                      onChange={(e) => {
                        const updatedAdvantages = [...content.advantages]
                        updatedAdvantages[index].description = e.target.value
                        updateContent("advantages", updatedAdvantages)
                      }}
                      className="bg-white/20 border-white/30 text-white min-h-[100px]"
                    />
                  </div>
                </CardContent>
              </Card>
            ))}

            <Button
              onClick={() => handleSaveSection("advantages")}
              disabled={isSaving}
              className="bg-green-500 hover:bg-green-600"
            >
              <Save className="mr-2 h-4 w-4" />
              {isSaving ? "Saving..." : "Save Changes"}
            </Button>
          </TabsContent>

          <TabsContent value="communities" className="space-y-4">
            <div className="flex justify-between items-center">
              <h2 className="text-xl font-playfair text-white">Communities</h2>
              <Button onClick={() => handleAddItem("communities")} variant="outline" className="text-white">
                <PlusCircle className="mr-2 h-4 w-4" /> Add Community
              </Button>
            </div>

            {content.communities.map((community: any, index: number) => (
              <Card key={index} className="bg-white/10 backdrop-blur-lg border-gray-200">
                <CardHeader className="flex flex-row items-center justify-between">
                  <CardTitle className="text-lg font-playfair text-white">Community {index + 1}</CardTitle>
                  <Button
                    variant="ghost"
                    onClick={() => handleRemoveItem("communities", index)}
                    className="text-red-400 hover:text-red-300 hover:bg-red-900/20"
                  >
                    <Trash2 className="h-4 w-4" />
                  </Button>
                </CardHeader>
                <CardContent className="space-y-4">
                  <div className="space-y-2">
                    <Label htmlFor={`community-${index}-name`} className="text-white">
                      Name
                    </Label>
                    <Input
                      id={`community-${index}-name`}
                      value={community.name}
                      onChange={(e) => {
                        const updatedCommunities = [...content.communities]
                        updatedCommunities[index].name = e.target.value
                        updateContent("communities", updatedCommunities)
                      }}
                      className="bg-white/20 border-white/30 text-white"
                    />
                  </div>

                  <div className="space-y-2">
                    <Label htmlFor={`community-${index}-description`} className="text-white">
                      Description
                    </Label>
                    <Textarea
                      id={`community-${index}-description`}
                      value={community.description}
                      onChange={(e) => {
                        const updatedCommunities = [...content.communities]
                        updatedCommunities[index].description = e.target.value
                        updateContent("communities", updatedCommunities)
                      }}
                      className="bg-white/20 border-white/30 text-white min-h-[100px]"
                    />
                  </div>

                  <div className="space-y-2">
                    <Label htmlFor={`community-${index}-url`} className="text-white">
                      URL
                    </Label>
                    <Input
                      id={`community-${index}-url`}
                      value={community.url}
                      onChange={(e) => {
                        const updatedCommunities = [...content.communities]
                        updatedCommunities[index].url = e.target.value
                        updateContent("communities", updatedCommunities)
                      }}
                      className="bg-white/20 border-white/30 text-white"
                    />
                  </div>
                </CardContent>
              </Card>
            ))}

            <Button
              onClick={() => handleSaveSection("communities")}
              disabled={isSaving}
              className="bg-green-500 hover:bg-green-600"
            >
              <Save className="mr-2 h-4 w-4" />
              {isSaving ? "Saving..." : "Save Changes"}
            </Button>
          </TabsContent>

          <TabsContent value="settings" className="space-y-4">
            <Card className="bg-white/10 backdrop-blur-lg border-gray-200">
              <CardHeader>
                <CardTitle className="text-xl font-playfair text-white">Admin Settings</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="text-white">Admin settings will be available here.</p>
              </CardContent>
            </Card>
          </TabsContent>
        </Tabs>
      </div>
    </div>
  )
}

